@@ -29,6 +29,7 @@
 
 #include <QTableWidget>
 #include <QLabel>
+#include <QShortcut>
 
 #include <libfm-qt/foldermodel.h>
 #include <libfm-qt/proxyfoldermodel.h>
@@ -70,9 +71,18 @@ public:
   }
 
   void setShowThumbnails(bool show);
+  void updateThumbnails();
+
   void setShowExifData(bool show);
   void applySettings();
 
+  void showAndRaise();
+  void setShowFullScreen(bool value) {
+    showFullScreen_ = value;
+  }
+
+  void setShortcuts(bool update = false);
+
 protected:
   void loadImage(const Fm::FilePath & filePath, QModelIndex index = QModelIndex());
   void saveImage(const Fm::FilePath & filePath); // save current image to a file
@@ -89,7 +99,9 @@ protected:
 
   virtual bool eventFilter(QObject* watched, QEvent* event);
 private Q_SLOTS:
+  void on_actionMenubar_triggered(bool checked);
   void on_actionAbout_triggered();
+  void on_actionHiddenShortcuts_triggered();
 
   void on_actionOpenFile_triggered();
   void on_actionOpenDirectory_triggered();
@@ -109,6 +121,7 @@ private Q_SLOTS:
   void on_actionResize_triggered();
   void on_actionCopy_triggered();
   void on_actionCopyPath_triggered();
+  void on_actionRenameFile_triggered();
   void on_actionPaste_triggered();
   void on_actionUpload_triggered();
 
@@ -179,9 +192,6 @@ private:
 
   // EXIF Data
   QDockWidget* exifDataDock_ = nullptr;
-  QWidget* exifDataDockView_;
-  QVBoxLayout* exifDataDockViewContent_;
-  QTableWidget* exifDataContentTable_;
 
   QMap<QString, QString> exifData_;
 
@@ -190,6 +200,10 @@ private:
   SaveImageJob* saveJob_;
 
   QPointer<Fm::FileMenu> fileMenu_;
+
+  bool showFullScreen_;
+
+  QMap<int, QShortcut*> hardCodedShortcuts_; // may be overriden by custom shortcuts
 };
 
 }
