@@ -29,7 +29,11 @@ Settings::Settings():
   useFallbackIconTheme_(QIcon::themeName().isEmpty() || QIcon::themeName() == QLatin1String("hicolor")),
   bgColor_(255, 255, 255),
   fullScreenBgColor_(0, 0, 0),
+  showExifData_(false),
+  exifDatakWidth_(250),
   showThumbnails_(false),
+  thumbnailSize_(64),
+  thumbnailsPosition_(Qt::BottomDockWidgetArea),
   showSidePane_(false),
   slideShowInterval_(5),
   fallbackIconTheme_(QStringLiteral("oxygen")),
@@ -40,8 +44,12 @@ Settings::Settings():
   lastWindowHeight_(480),
   lastWindowMaximized_(false),
   showOutline_(false),
+  showMenubar_(true),
+  showToolbar_(true),
   showAnnotationsToolbar_(false),
-  forceZoomFit_(false) {
+  forceZoomFit_(false),
+  smoothOnZoom_(true),
+  useTrash_(true) {
 }
 
 Settings::~Settings() {
@@ -65,8 +73,14 @@ bool Settings::load() {
   lastWindowMaximized_ = settings.value(QStringLiteral("LastWindowMaximized"), false).toBool();
   rememberWindowSize_ = settings.value(QStringLiteral("RememberWindowSize"), true).toBool();
   showOutline_ = settings.value(QStringLiteral("ShowOutline"), false).toBool();
+  showExifData_ = settings.value(QStringLiteral("ShowExifData"), false).toBool();
+  exifDatakWidth_ = settings.value(QStringLiteral("ExifDatakWidth"), 250).toInt();
+  showMenubar_ = settings.value(QStringLiteral("ShowMenubar"), true).toBool();
+  showToolbar_ = settings.value(QStringLiteral("ShowToolbar"), true).toBool();
   showAnnotationsToolbar_ = settings.value(QStringLiteral("ShowAnnotationsToolbar"), false).toBool();
   forceZoomFit_ = settings.value(QStringLiteral("ForceZoomFit"), false).toBool();
+  smoothOnZoom_ = settings.value(QStringLiteral("SmoothOnZoom"), true).toBool();
+  useTrash_ = settings.value(QStringLiteral("UseTrash"), true).toBool();
   prefSize_ = settings.value(QStringLiteral("PrefSize"), QSize(400, 400)).toSize();
   settings.endGroup();
 
@@ -81,7 +95,9 @@ bool Settings::load() {
 
   settings.beginGroup(QStringLiteral("Thumbnail"));
   showThumbnails_ = settings.value(QStringLiteral("ShowThumbnails"), false).toBool();
+  thumbnailsPositionFromString(settings.value(QStringLiteral("ThumbnailsPosition")).toString());
   setMaxThumbnailFileSize(qMax(settings.value(QStringLiteral("MaxThumbnailFileSize"), 4096).toInt(), 1024));
+  setThumbnailSize(settings.value(QStringLiteral("ThumbnailSize"), 64).toInt());
   settings.endGroup();
 
   return true;
@@ -105,8 +121,14 @@ bool Settings::save() {
   settings.setValue(QStringLiteral("LastWindowMaximized"), lastWindowMaximized_);
   settings.setValue(QStringLiteral("RememberWindowSize"), rememberWindowSize_);
   settings.setValue(QStringLiteral("ShowOutline"), showOutline_);
+  settings.setValue(QStringLiteral("ShowMenubar"), showMenubar_);
+  settings.setValue(QStringLiteral("ShowToolbar"), showToolbar_);
   settings.setValue(QStringLiteral("ShowAnnotationsToolbar"), showAnnotationsToolbar_);
+  settings.setValue(QStringLiteral("ShowExifData"), showExifData_);
+  settings.setValue(QStringLiteral("ExifDatakWidth"), exifDatakWidth_);
   settings.setValue(QStringLiteral("ForceZoomFit"), forceZoomFit_);
+  settings.setValue(QStringLiteral("SmoothOnZoom"), smoothOnZoom_);
+  settings.setValue(QStringLiteral("UseTrash"), useTrash_);
   settings.setValue(QStringLiteral("PrefSize"), prefSize_);
   settings.endGroup();
 
@@ -124,10 +146,53 @@ bool Settings::save() {
 
   settings.beginGroup(QStringLiteral("Thumbnail"));
   settings.setValue(QStringLiteral("ShowThumbnails"), showThumbnails_);
+  settings.setValue(QStringLiteral("ThumbnailsPosition"), thumbnailsPositionToString());
   settings.setValue(QStringLiteral("MaxThumbnailFileSize"), maxThumbnailFileSize());
+  settings.setValue(QStringLiteral("ThumbnailSize"), thumbnailSize_);
   settings.endGroup();
 
   return true;
 }
 
+const QList<int>& Settings::thumbnailSizes() const {
+  static const QList<int> _thumbnailSizes = {256, 224, 192, 160, 128, 96, 64};
+  return _thumbnailSizes;
+}
+
+void Settings::setThumbnailsPosition(int pos) {
+  switch(pos) {
+    case Qt::TopDockWidgetArea:
+      thumbnailsPosition_ = Qt::TopDockWidgetArea;
+      break;
+    case Qt::LeftDockWidgetArea:
+      thumbnailsPosition_ = Qt::LeftDockWidgetArea;
+      break;
+    default:
+      thumbnailsPosition_ = Qt::BottomDockWidgetArea;
+      break;
+  }
+}
+
+QString Settings::thumbnailsPositionToString() const {
+  switch(thumbnailsPosition_) {
+    case Qt::TopDockWidgetArea:
+      return QStringLiteral("top");
+    case Qt::LeftDockWidgetArea:
+      return QStringLiteral("left");
+    default:
+      return QStringLiteral("bottom");
+  }
+}
+
+void Settings::thumbnailsPositionFromString(const QString& str) {
+  if(str == QStringLiteral("top")) {
+    thumbnailsPosition_ = Qt::TopDockWidgetArea;
+    return;
+  }
+  if(str == QStringLiteral("left")) {
+    thumbnailsPosition_ = Qt::LeftDockWidgetArea;
+    return;
+  }
+  thumbnailsPosition_ = Qt::BottomDockWidgetArea;
+}
 
